"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const roleReflectionToken = 'nestjs-roles';
function createRolesGuard(getRole) {
    var _a;
    return _a = class RolesGuard {
            constructor(reflector) {
                this.reflector = reflector;
            }
            canActivate(context) {
                const requiredRoles = this.reflector.getAllAndOverride(roleReflectionToken, [context.getHandler(), context.getClass()]);
                // roles are not set - handler is allowed for all
                if (!requiredRoles || !requiredRoles.length) {
                    return true;
                }
                const role = getRole(context);
                // handler is allowed only for not authorized
                if (requiredRoles[0] === false) {
                    // but there is some role
                    if (role) {
                        throw new common_1.ForbiddenException();
                    }
                    // handler is allowed for surtain roles
                }
                else {
                    // there is no any role
                    if (!role) {
                        throw new common_1.UnauthorizedException();
                    }
                    // role is not one of requireds
                    if (!requiredRoles.includes(role)) {
                        throw new common_1.ForbiddenException();
                    }
                }
                return true;
            }
        },
        /**
         * Decorator for controller or handler to specify allowed roles.
         * For surtain roles pass it to decorator.
         * Pass `false` to make controller or handler be allowed only for
         * unauthorized users.
         * Do not use it to make controller or handler bew allowed for all.
         */
        _a.Params = (...allowedRoles) => common_1.SetMetadata(roleReflectionToken, allowedRoles),
        _a;
}
exports.createRolesGuard = createRolesGuard;
//# sourceMappingURL=index.js.map